      subroutine tslc(a,x,r,m)
      integer m
      complex a(1),x(m),r(1)
c
c     tslc calls tslc1 to solve the complex linear system
c     a * x = b
c     with the t - matrix a .
c
c     on entry
c
c        a       complex(2*m - 1)
c                the first row of the t - matrix followed by its
c                first column beginning with the second element .
c                on return a is unaltered .
c
c        x       complex(m)
c                the right hand side vector b .
c
c        r       complex(2*m - 2)
c                a work vector .
c
c        m       integer
c                the order of the matrix a .
c
c     on return
c
c        x       the solution vector .
c
c     toeplitz package. this version dated 07/23/82 .
c
c     subroutines and functions
c
c        toeplitz package ... tslc1
c
c     call subroutine tslc1
c
      call tslc1(a,a(m+1),x,x,r,r(m),m)
c
      return
      end